@@ -19,17 +19,16 @@ def main():
         '-o',
         '--output',
         type=str,
-        default='addressbook',
+        default='./addressbook',
         help="the output path/filename (default: ./addressbook)"
     )
 
-    '''
     parser.add_argument(
         '-a',
-        '--add',
+        '--append',
+        action='store_true',
         help="append new contacts to existing address book"
     )
-    '''
     args = parser.parse_args()
 
     vcftoabook.main(args)
