@@ -3,7 +3,7 @@ import re
 
 def parse_vcf(items):
     """
-    Load a given vcf, parse it and attempt to return a usable dictionary
+    Parse data from a vcf and attempt to return a usable dictionary
     """
     items = list(filter(lambda x: x != '', items.split('\n')))
 
@@ -25,3 +25,16 @@ def parse_vcf(items):
             entry['custom1'] = item.split(':')[1]
 
     return entry
+
+
+def parse_contact(contact, configparser):
+    """
+    Parse data from an abook file and return a usable dictionary
+    """
+
+    return {
+        'name': configparser[contact].get('name'),
+        'email': set(configparser[contact].get('email').split(',')),
+        'notes': configparser[contact].get('notes'),
+        'custom1': configparser[contact].get('custom1')
+    }
